.. highlight:: shell

============
Installation
============


--------------------
Stable Release (Pip)
--------------------

To install CADA, run this command in your terminal:

.. code-block:: console

    $ pip install cada-prio

This is the preferred method to install CADA, as it will always install the most recent stable release.

If you don't have `pip <https://pip.pypa.io>`__ installed, this `Python installation guide <http://docs.python-guide.org/en/latest/starting/installation/>`__ can guide you through the process.


------------
From Sources
------------

The sources for CADA can be downloaded from the `Github repo <https://github.com/bihealth/cada-prio>`__.

Clone the public repository:

.. code-block:: console

    $ git clone https://github.com/bihealth/cada-prio.git
